/*
 * Extensive INTERVAL function tests.
 * OUTPUT STREAM TO "OUTPUT.txt".
 */

DEFINE STREAM toFile.
OUTPUT STREAM toFile TO "date-time-tz-interval-tests-to-file.txt".

DISPLAY STREAM toFile "MLS" INTERVAL(2000-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "milliseconds") SKIP.
DISPLAY STREAM toFile "Sec" INTERVAL(2000-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "seconds") SKIP.
DISPLAY STREAM toFile "min" INTERVAL(2000-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "minute") SKIP.
DISPLAY STREAM toFile "hrs" INTERVAL(2000-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "hours") SKIP.
DISPLAY STREAM toFile "day" INTERVAL(2000-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "day") SKIP.
DISPLAY STREAM toFile "wek" INTERVAL(2000-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "week") SKIP.
DISPLAY STREAM toFile "mnt" INTERVAL(2000-10-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "months") SKIP.
DISPLAY STREAM toFile "mnt" INTERVAL(2000-12-31T23:59:59+01:01, 2000-10-31T23:59:59-01:01, "months") SKIP.
DISPLAY STREAM toFile "Yrs" INTERVAL(2001-12-31T23:59:59+01:01, 2000-12-31T23:59:59-01:01, "year") SKIP.
DISPLAY STREAM toFile "Yrs" INTERVAL(2000-12-31T23:59:59+01:01, 2001-12-31T23:59:59-01:01, "year") SKIP.


DEFINE VARIABLE dd AS DATE EXTENT 9.
ASSIGN
    dd[1] = 12/31/2050
    dd[2] = 10/04/1582
    dd[3] = 10/15/1582
    dd[4] = 01/01/001
    dd[5] = 06/15/1974
    dd[6] = 04/05/-4716
    dd[7] = 05/13/2013
    dd[8] = 01/01/1900
    dd[9] = 05/13/2013.

DEFINE VARIABLE dt AS DATETIME EXTENT 9.
ASSIGN
    dt[1] = 2050-12-31T10:30:21.555
    dt[2] = 1582-10-04T16:48:31.123
    dt[3] = 1582-10-15T00:00:00.000
    dt[4] = 0001-01-01T06:18:20.192
    dt[5] = 1974-06-15T21:45:56.483
    dt[6] = 4716-04-05T12:58:31.000
    dt[7] = 2013-05-13T02:35:40.623
    dt[8] = 1900-01-01T20:06:22.002
    dt[9] = 2013-05-13T15:15:15.155.

DEFINE VARIABLE dz AS DATETIME-TZ EXTENT 9.
ASSIGN
    dz[1] = 2050-12-31T10:30:21.555+10:00
    dz[2] = 1582-10-04T16:48:31.123+03:30
    dz[3] = 1582-10-15T00:00:00.000-02:00
    dz[4] = 0001-01-01T06:18:20.192-06:00
    dz[5] = 1974-06-15T21:45:56.483+00:00
    dz[6] = 4716-04-05T12:58:31.000+07:45
    dz[7] = 2013-05-13T02:35:40.623+04:00
    dz[8] = 1900-01-01T20:06:22.002-06:00
    dz[9] = 2013-05-13T15:15:15.155-01:30.

DEFINE VARIABLE it1 AS INT64.
REPEAT it1 = 1 TO 9:
    DISPLAY STREAM toFile STRING(
        ISO-DATE(dd[it1]) + " " + ISO-DATE(dt[it1]) + " " + ISO-DATE(dz[it1])) 
        FORMAT "x(76)".
END.

FUNCTION run-test-dd RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATE 2 DATE " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dd[i + 1], dd[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

FUNCTION run-test-td RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATETIME 2 DATE " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dt[i + 1], dd[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

FUNCTION run-test-zd RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATETIME-TZ 2 DATE " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dz[i + 1], dd[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.


FUNCTION run-test-dt RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATE 2 DATETIME " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dd[i + 1], dt[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

FUNCTION run-test-tt RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATETIME 2 DATETIME " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dt[i + 1], dt[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

FUNCTION run-test-zt RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATETIME-TZ 2 DATETIME " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dz[i + 1], dt[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.


FUNCTION run-test-dz RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATE 2 DATETIME-TZ " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dd[i + 1], dz[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

FUNCTION run-test-tz RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATETIME 2 DATETIME-TZE " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dt[i + 1], dz[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

FUNCTION run-test-zz RETURN LOGICAL (INPUT unit AS CHARACTER):
   DEFINE VARIABLE i AS INT.
   DEFINE VARIABLE j AS INT.
   DISPLAY STREAM toFile SKIP "DATETIME-TZ 2 DATETIME-TZ " + unit FORMAT "x(50)" SKIP.
   REPEAT i = 0 TO 8:
      REPEAT j = 0 TO 8 :
         DISPLAY STREAM toFile STRING(INTERVAL(dz[i + 1], dz[j + 1], unit)) FORMAT "x(30)".
      END.
   END.
END.

DEFINE VARIABLE units AS CHARACTER EXTENT 8 INITIAL ["milliseconds", "second", 
               "minutes", "hours", "days", "weeks", "months", "years"].

DEFINE VARIABLE it AS INT.
REPEAT it = 1 TO 8:
   /* run-test-dd(units[it]). */
   /* run-test-td(units[it]). */
   /* run-test-zd(units[it]). */

   /* run-test-dt(units[it]). */
   /* run-test-tt(units[it]). */
   run-test-zt(units[it]).

   /* run-test-dz(units[it]). */
   run-test-tz(units[it]).
   /* run-test-zz(units[it]). */
END.




